#!/usr/bin/env python3

from typing import Dict, List, Tuple

import lhotse
from gigaspeech_scoring import asr_text_post_processing
from icefall.utils import store_transcripts, write_error_stats
from lhotse import CutSet, load_manifest
from pathlib import Path


def post_processing(
    results: List[Tuple[str, List[str], List[str]]],
) -> List[Tuple[str, List[str], List[str]]]:
    new_results = []
    for key, ref, hyp in results:
        new_ref = asr_text_post_processing(" ".join(ref)).split()
        new_hyp = asr_text_post_processing(" ".join(hyp)).split()
        new_results.append((key, new_ref, new_hyp))
    return new_results


def main():
    filename = "/ceph-fj/fangjun/open-source/icefall-dan-second-giga-libri/egs/librispeech/ASR/data/fbank/gigaspeech_cuts_DEV.jsonl.gz"
    cuts = lhotse.load_manifest(filename)

    filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-2-greedy_search.ark"
    filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-2-modified_beam_search.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-greedy_search-padding-0.8.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-modified_beam_search-padding-0.8.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-2-greedy_search-padding-0.8.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-2-modified_beam_search-padding-0.8.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-greedy_search-padding-1.0.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-modified_beam_search-padding-1.0.ark"
    #  filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-greedy_search-padding-0.6.ark"
    filename = "/ceph-fj/fangjun/open-source/sherpa/build/giga-dev-chunk-size-16-left-context-64-right-context-0-modified_beam_search-padding-0.6.ark"
    hyps: Dict[str, str] = {}
    with open(filename) as f:
        for line in f:
            hyp = line.strip().split(maxsplit=1)
            if len(hyp) == 1:
                hyp.append("")
            hyps[hyp[0]] = hyp[1]

    results = []
    for c in cuts:
        hyp = hyps[c.id].split()
        ref = c.supervisions[0].text.split()
        results.append((c.id, ref, hyp))

    results = post_processing(results)
    results = sorted(results)
    name = Path(filename).name
    store_transcripts(filename=f"recogs-{name}.txt", texts=results)
    print(f"saved to recogs-{name}.txt")

    with open(f"errs-{name}.txt", "w") as f:
        write_error_stats(f, "test-set", results, enable_log=True)

    print(f"saved to errs-{name}.txt")

    with open(f"errs-{name}.txt", "r") as f:
        print(f.readline())  # WER
        print(f.readline())  # Detailed errors


if __name__ == "__main__":
    main()
